@@ -8,6 +8,12 @@ from cameramodels import PinholeCameraModel
 
 class TestPinholeCameraModel(unittest.TestCase):
 
+    cm = None
+
+    @classmethod
+    def setUpClass(cls):
+        cls.cm = PinholeCameraModel.from_fovy(45, 480, 640)
+
     def test_calc_f_from_fov(self):
         f = PinholeCameraModel.calc_f_from_fov(90, 480)
         testing.assert_almost_equal(
@@ -31,8 +37,12 @@ class TestPinholeCameraModel(unittest.TestCase):
     def test_from_fovy(self):
         PinholeCameraModel.from_fovy(45, 480, 640)
 
+    def test_open3d_intrinsic(self):
+        cm = self.cm
+        cm.open3d_intrinsic
+
     def test_batch_project3d_to_pixel(self):
-        cm = PinholeCameraModel.from_fovy(45, 480, 640)
+        cm = self.cm
         cm.batch_project3d_to_pixel(
             np.array([[10, 0, 1],
                       [0, 0, 1]]))
